import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import {AdminAuthGuard} from "src/core/guards/admin-auth.guard";
import {Constants} from "src/utils/constants";
import {FileFieldsInterceptor} from "@nestjs/platform-express";
import {UploadedMulterFileI} from "src/modules/SpacesModule/SpacesService";
import {HeaderFooterCmsService} from "./header-footer-cms.service";
import {UpdateHeaderFooterCmsDto} from "./dto/update-header-footer-cms.dto";

@Controller({path: "header-footer-cms", version: Constants.API_VERSION_1})

export class HeaderFooterCmsController {
    constructor(private readonly service: HeaderFooterCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            {name: "siteLogo", maxCount: 1},
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateHeaderFooterCmsDto,
        @UploadedFiles() files: {
            siteLogo: UploadedMulterFileI,
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
