import {HttpException, HttpStatus, Injectable} from '@nestjs/common';
import {SigninCmsDto} from './dto/signin-cms.dto';
import {SigninCmsRepository} from "./signin-cms.repository";
import {InjectRepository} from "@nestjs/typeorm";
import {SigninCms} from "./entities/signin-cms.entity";
import {Constants} from "src/utils/constants";
import {ResponseUtils} from "src/utils/response.utils";
import {UploadedMulterFileI} from "src/modules/SpacesModule/SpacesService";
import {DoSpacesService} from "src/modules/SpacesModule/SpacesService/doSpacesService";

@Injectable()
export class SigninCmsService {
    constructor(
        @InjectRepository(SigninCmsRepository) private readonly repository: SigninCmsRepository,
        private readonly doSpacesService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
        dto: SigninCmsDto,
        files: {
            googleButtonIcon?: UploadedMulterFileI,
            facebookButtonIcon?: UploadedMulterFileI,
            logo?: UploadedMulterFileI,
        }
    ): Promise<SigninCms | Error> {
        const isExists = await this.repository.find({isDeleted: false});

        if (files && files.googleButtonIcon) {
            const url = await this.doSpacesService.uploadFile(files.googleButtonIcon[0], "SigninContent/");
            dto.googleButtonIcon = url.toString();
        }
        if (files && files.facebookButtonIcon) {
            const url = await this.doSpacesService.uploadFile(files.facebookButtonIcon[0], "SigninContent/");
            dto.facebookButtonIcon = url.toString();
        }
        if (files && files.logo) {
            const url = await this.doSpacesService.uploadFile(files.logo[0], "SigninContent/");
            dto.logo = url.toString();
        }

        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<SigninCms[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}
