import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from '@nestjs/common';
import {SignupCmsService} from './signup-cms.service';
import {SignupCmsDto} from './dto/signup-cms.dto';
import {AdminAuthGuard} from "src/core/guards/admin-auth.guard";
import {Constants} from "src/utils/constants";
import {FileFieldsInterceptor} from "@nestjs/platform-express";
import {UploadedMulterFileI} from "src/modules/SpacesModule/SpacesService";

@Controller({path: "signup-cms", version: Constants.API_VERSION_1})
export class SignupCmsController {
    constructor(private readonly service: SignupCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'logo', maxCount: 1}
    ]))
    updateOrCreateData(
        @Body() dto: SignupCmsDto,
        @UploadedFiles() files: {
            logo?: UploadedMulterFileI,
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    findAll() {
        return this.service.findAll();
    }
}
