import {EntityRepository, getConnection, Repository} from "typeorm";
import {CreateAccelerateContentDto} from "./dto/create-accelerate-content.dto";
import {UpdateAccelerateContentDto} from "./dto/update-accelerate-content.dto";
import {AccelerateContentEntity} from "./entity/accelerate-content.entity";

@EntityRepository(AccelerateContentEntity)
export class AccelerateContentRepository extends Repository<AccelerateContentEntity> {
    async createEntity(dto: CreateAccelerateContentDto): Promise<AccelerateContentEntity | Error> {
        try {
            const {
                description,
                image
            } = dto;
            const entity = this.create({
                description,
                image
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<AccelerateContentEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateAccelerateContentDto): Promise<AccelerateContentEntity | Error> {
        try {
            await this.update(id, {
                description: dto.description,
                image: dto.image
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<AccelerateContentEntity[] | Error> {
        try {
            return await this.find({
                where: {...query, isDeleted: false}
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(AccelerateContentEntity)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}