import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from '@nestjs/common';
import {AuthCommonDataService} from './auth-common-data.service';
import {CreateAuthCommonDataDto} from './dto/create-auth-common-data.dto';
import {UpdateAuthCommonDataDto} from './dto/update-auth-common-data.dto';
import {AdminAuthGuard} from "src/core/guards/admin-auth.guard";
import {FileFieldsInterceptor} from "@nestjs/platform-express";
import {UploadedMulterFileI} from "src/modules/SpacesModule/SpacesService";
import {Constants} from "src/utils/constants";

@Controller({path: 'auth-common-data', version: Constants.API_VERSION_1})
export class AuthCommonDataController {
    constructor(private readonly service: AuthCommonDataService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'icon', maxCount: 1}
    ]))
    @Post()
    create(
        @Body() dto: CreateAuthCommonDataDto,
        @UploadedFiles() files: {
            icon?: UploadedMulterFileI,
        }
    ) {
        return this.service.create(dto, files);
    }

    @Get()
    findAll() {
        return this.service.findAll();
    }

    @Get(':id')
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch(':id')
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'icon', maxCount: 1},
    ]))
    update(
        @Param('id') id: string,
        @Body() dto: UpdateAuthCommonDataDto,
        @UploadedFiles() files: {
            icon?: UploadedMulterFileI,
        }
    ) {
        return this.service.update(id, dto, files);
    }

    @Delete(':id')
    remove(@Param('id') id: string) {
        return this.service.remove(id);
    }
}
