import {EntityRepository, getConnection, Repository} from "typeorm";
import {CreateBenefitsAndAdvantageSectionDto} from "./dto/create-benefits-and-advantage-section.dto";
import {UpdateBenefitsAndAdvantageSectionDto} from "./dto/update-benefits-and-advantage-section.dto";
import {BenefitsAndAdvantageSectionEntity} from "./entity/benefits-and-advantage-section.entity";

@EntityRepository(BenefitsAndAdvantageSectionEntity)
export class BenefitsAndAdvantageSectionRepository extends Repository<BenefitsAndAdvantageSectionEntity> {

    async createEntity(dto: CreateBenefitsAndAdvantageSectionDto): Promise<BenefitsAndAdvantageSectionEntity | Error> {
        try {
            const {
                image,
                title,
                description,
                buttonLink,
                buttonText
            } = dto;
            const entity = this.create({
                image,
                title,
                description,
                buttonLink,
                buttonText
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<BenefitsAndAdvantageSectionEntity[] | Error> {
        try {
            return await this.find({
                where: {...query, isDeleted: false}
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<BenefitsAndAdvantageSectionEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateBenefitsAndAdvantageSectionDto): Promise<BenefitsAndAdvantageSectionEntity | Error> {
        try {
            await this.update(id, {
                image: dto.image,
                title: dto.title,
                description: dto.description,
                buttonLink: dto.buttonLink,
                buttonText: dto.buttonText
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(BenefitsAndAdvantageSectionEntity)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}