import {Body, Controller, Delete, Get, Param, Patch, Post, UseGuards} from '@nestjs/common';
import {AdminAuthGuard} from 'src/core/guards/admin-auth.guard';
import {Constants} from 'src/utils/constants';
import {HomePageHeroSectionService} from './home-page-hero-section.service';
import {CreateHomePageHeroSectionDto} from './dto/create-home-page-hero-section.dto';
import {UpdateHomePageHeroSectionDto} from './dto/update-home-page-hero-section.dto';

@Controller({path: 'home-page-hero-section', version: Constants.API_VERSION_1})
export class HomePageHeroSectionController {
    constructor(private readonly service: HomePageHeroSectionService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    create(@Body() dto: CreateHomePageHeroSectionDto) {
        return this.service.create(dto);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch(':id')
    @UseGuards(AdminAuthGuard)
    update(@Param('id') id: string, @Body() dto: UpdateHomePageHeroSectionDto) {
        return this.service.update(id, dto);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
