import {EntityRepository, getConnection, Repository} from "typeorm";
import {CreateScheduleModelDto} from "./dto/create-schedule-model.dto";
import {UpdateScheduleModelDto} from "./dto/update-schedule-model.dto";
import {ScheduleModelEntity} from "./entity/schedule-model.entity";

@EntityRepository(ScheduleModelEntity)
export class ScheduleModelRepository extends Repository<ScheduleModelEntity> {

    async createEntity(dto: CreateScheduleModelDto): Promise<ScheduleModelEntity | Error> {
        try {
            const {
                firstName,
                lastName,
                email,
                phone,
                role,
                transactionNumber,
                industry
            } = dto;
            const entity = this.create({
                firstName,
                lastName,
                email,
                phone,
                role,
                transactionNumber,
                industry
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<ScheduleModelEntity[] | Error> {
        try {
            return await this.find({
                where: {...query, isDeleted: false}
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<ScheduleModelEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateScheduleModelDto): Promise<ScheduleModelEntity | Error> {
        try {
            await this.update(id, dto);
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(ScheduleModelEntity)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

    async countAllQuery(): Promise<any | Error> {
        try {
            return await this.count({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}