import { WebSocketGateway, SubscribeMessage, MessageBody, WebSocketServer } from '@nestjs/websockets';
import { NotificationService } from './notification.service';
import { CreateNotificationDto } from './dto/create-notification.dto';
import { Server } from 'socket.io';
import { NotificationByUserIdDto } from "./dto/notification-by-userid.dto";
import { UpdateNotificationDto } from "./dto/update-notification.dto";

@WebSocketGateway({ cors: { origin: '*' } })
export class NotificationGateway {
  @WebSocketServer() server: Server;

  constructor(private readonly notificationService: NotificationService) {}

  @SubscribeMessage('createNotification')
  create(@MessageBody() dto: CreateNotificationDto) {
    const notification = this.notificationService.create(dto);
    this.server.emit(`singleNotification_${dto.userId}`, notification);
    return notification;
  }

  @SubscribeMessage('findNotificationsByUserId')
  findNotificationsByUserId(@MessageBody() dto: NotificationByUserIdDto) {
    return this.notificationService.findNotificationsByUserId(dto);
  }

  @SubscribeMessage('updateNotification')
  update(@MessageBody() dto: UpdateNotificationDto) {
    return this.notificationService.update(dto);
  }

  // @SubscribeMessage('removeNotification')
  // remove(@MessageBody() id: number) {
  //   return this.notificationService.remove(id);
  // }
}
