import { EntityRepository, getConnection, Repository } from "typeorm";
import { Notification } from "./entities/notification.entity";
import { CreateNotificationDto } from "./dto/create-notification.dto";

@EntityRepository(Notification)
export class NotificationRepository extends Repository<Notification> {
    async createEntity(dto: CreateNotificationDto): Promise<Notification | Error> {
        try {
            const entity = this.create({...dto});
            const data = await this.save(entity);
            return data;
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<Notification[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false },
                order: { createdAt: "DESC" }
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<Notification | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: any): Promise<any | Error> {
        try {
            return await this.update(id, { ...dto });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(Notification)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}