import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { FileUploadsService } from 'src/modules/file-uploads/file-uploads.service';

import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { CreateTransactionAddressDetailsDto } from './dto/create-transaction-address-details.dto';
import { TransactionAddressDetailsEntity } from './entity/transaction-address-details.entity';
import { TransactionAddressDetailsRepository } from './transaction-address-details.repository';
import { UpdateTransactionAddressDetailsDto } from './dto/update-transaction-address-details.dto';
import { TransactionRepository } from '../transaction/transaction.repository';

@Injectable()
export class TransactionAddressDetailsService {
    constructor(
        @InjectRepository(TransactionAddressDetailsRepository)
        private readonly repository: TransactionAddressDetailsRepository,
        @InjectRepository(TransactionRepository)
        private readonly transactionRepository: TransactionRepository,
    ) {
    }

    async create(
        dto: CreateTransactionAddressDetailsDto,
        request: any
    ): Promise<TransactionAddressDetailsEntity | Error> {
        const transaction: any = await this.transactionRepository.findByFilterQuery({ id: dto.transactionId });
        if (!transaction.length) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
    }

    async update(
        id: string,
        dto: UpdateTransactionAddressDetailsDto,
        request: any
    ): Promise<TransactionAddressDetailsEntity | Error> {
        const res: any = await this.repository.findOneEntity(id);
        if (!res) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        const { transactionId, ...updateDto } = dto;
        const data = await this.repository.updateEntity(id, updateDto);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
    }

    async findAll(): Promise<TransactionAddressDetailsEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<TransactionAddressDetailsEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({ id: id });
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
    }
}
