import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    Req,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from '@nestjs/common';
import {FileFieldsInterceptor} from '@nestjs/platform-express';
import {Constants} from 'src/utils/constants';
import {TransactionNotesService} from './transaction-notes.service';
import {CreateTransactionNotesDto} from './dto/create-transaction-notes.dto';
import {UpdateTransactionNotesDto} from './dto/update-transaction-notes.dto';
import {UploadedMulterFileI} from 'src/modules/SpacesModule/SpacesService';
import {AuthGuard} from "../../core/guards/auth.guard";

@Controller({path: 'transaction-notes', version: Constants.API_VERSION_1})

export class TransactionNotesController {
    constructor(private readonly service: TransactionNotesService) {
    }

    @Post()
    @UseGuards(AuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'file', maxCount: 1}
    ]))
    create(
        @Body() dto: CreateTransactionNotesDto,
        @UploadedFiles() files: {
            file?: UploadedMulterFileI
        },
        @Req() request: any
    ) {
        return this.service.create(dto, files, request);
    }

    @Get(':transactionId')
    @UseGuards(AuthGuard)
    findAll(@Param('transactionId') transactionId: string) {
        return this.service.findAll(transactionId);
    }

    @Get(':id')
    @UseGuards(AuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch('/:id')
    @UseGuards(AuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'file', maxCount: 1}
    ]))
    update(
        @Param('id') id: string,
        @Body() dto: UpdateTransactionNotesDto,
        @UploadedFiles() files: {
            file?: UploadedMulterFileI
        },
        @Req() request: any
    ) {
        return this.service.update(id, dto, files, request);
    }

    @Delete(':id')
    @UseGuards(AuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
