import {EntityRepository, getConnection, Repository} from "typeorm";
import {CreateTransactionNotesDto} from "./dto/create-transaction-notes.dto";
import {UpdateTransactionNotesDto} from "./dto/update-transaction-notes.dto";
import {TransactionNotesEntity} from "./entity/transaction-notes.entity";

@EntityRepository(TransactionNotesEntity)
export class TransactionNotesRepository extends Repository<TransactionNotesEntity> {
    async createEntity(dto: CreateTransactionNotesDto): Promise<TransactionNotesEntity | Error> {
        try {
            const {
                transactionId,
                userId,
                message,
                file
            } = dto;
            const entity = this.create({
                transactionId,
                userId,
                message,
                file
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<TransactionNotesEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateTransactionNotesDto): Promise<TransactionNotesEntity | Error> {
        try {
            await this.update(id, {
                transactionId: dto.transactionId,
                userId: dto.userId,
                message: dto.message,
                file: dto.file
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<TransactionNotesEntity[] | Error> {
        try {
            return await this.find({
                where: {
                    ...query,
                    isDeleted: false
                },
                order: {
                    createdAt: "ASC"
                }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(TransactionNotesEntity)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            return updateResult.affected > 0;

        } catch (e) {
            return e;
        }
    }
}